@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::SHANTANU;
 
 # PODNAME: Dist::Zilla::PluginBundle::SHANTANU
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -60,6 +60,7 @@ use Dist::Zilla::Plugin::MakeMaker::Awesome;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
 use Dist::Zilla::Plugin::CheckMetaResources;
 use Dist::Zilla::Plugin::CheckPrereqsIndexed;
+use Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes;
 use Dist::Zilla::Plugin::CheckChangesHasContent;
 use Dist::Zilla::Plugin::CheckExtraTests;
 
@@ -383,7 +384,12 @@ sub configure {
         ),
         'CheckMetaResources',
         'CheckPrereqsIndexed',
-        'CheckChangesHasContent',
+        [
+            'ChangelogFromGit::CPAN::Changes' => {
+                tag_regexp             => '^release-(\d+\.\d+)$',
+                parse_version_from_tag => 1,
+            }
+        ],
         'CheckExtraTests',
         'TestRelease',       # core
         'ConfirmRelease',    # core
@@ -456,7 +462,7 @@ Dist::Zilla::PluginBundle::SHANTANU - Dist Zilla Plugin Bundle the way I like to
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
